
# Teamtailor Connector

> The new way to attract, nurture and hire top talent. Grow faster by focusing on what matters the most — your candidates


🔗 https://www.teamtailor.com/

| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
| [**Push profile**](docs/push_profile.md) |
